pub struct FormatSpecifier {
pub raw: String,
pub position: Option<u32>,
pub conversion: char,
pub length_modifier: Option<String>,
}Fields
raw: Stringposition: Option<u32>conversion: charlength_modifier: Option<String>Trait Implementations
Sourceimpl Clone for FormatSpecifier
impl Clone for FormatSpecifier
Sourcefn clone(&self) -> FormatSpecifier
fn clone(&self) -> FormatSpecifier
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FormatSpecifier
impl Debug for FormatSpecifier
Sourceimpl<'de> Deserialize<'de> for FormatSpecifier
impl<'de> Deserialize<'de> for FormatSpecifier
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FormatSpecifier
impl JsonSchema for FormatSpecifier
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FormatSpecifier
impl PartialEq for FormatSpecifier
Sourceimpl Serialize for FormatSpecifier
impl Serialize for FormatSpecifier
impl Eq for FormatSpecifier
impl StructuralPartialEq for FormatSpecifier