pub struct RejectedTranslation {
pub key: String,
pub reason: String,
}Fields
key: Stringreason: StringTrait Implementations
Sourceimpl Clone for RejectedTranslation
impl Clone for RejectedTranslation
Sourcefn clone(&self) -> RejectedTranslation
fn clone(&self) -> RejectedTranslation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RejectedTranslation
impl Debug for RejectedTranslation
Sourceimpl<'de> Deserialize<'de> for RejectedTranslation
impl<'de> Deserialize<'de> for RejectedTranslation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RejectedTranslation
impl JsonSchema for RejectedTranslation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RejectedTranslation
impl RefUnwindSafe for RejectedTranslation
impl Send for RejectedTranslation
impl Sync for RejectedTranslation
impl Unpin for RejectedTranslation
impl UnsafeUnpin for RejectedTranslation
impl UnwindSafe for RejectedTranslation