pub struct TranslationUnit {
pub key: String,
pub source_text: String,
pub target_locale: String,
pub comment: Option<String>,
pub format_specifiers: Vec<String>,
pub has_plurals: bool,
pub has_substitutions: bool,
}Fields
key: Stringsource_text: Stringtarget_locale: Stringcomment: Option<String>format_specifiers: Vec<String>has_plurals: boolhas_substitutions: boolTrait Implementations
Sourceimpl Clone for TranslationUnit
impl Clone for TranslationUnit
Sourcefn clone(&self) -> TranslationUnit
fn clone(&self) -> TranslationUnit
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TranslationUnit
impl Debug for TranslationUnit
Sourceimpl<'de> Deserialize<'de> for TranslationUnit
impl<'de> Deserialize<'de> for TranslationUnit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TranslationUnit
impl JsonSchema for TranslationUnit
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TranslationUnit
impl RefUnwindSafe for TranslationUnit
impl Send for TranslationUnit
impl Sync for TranslationUnit
impl Unpin for TranslationUnit
impl UnsafeUnpin for TranslationUnit
impl UnwindSafe for TranslationUnit