pub struct DeviceVariation {
pub string_unit: StringUnit,
}Fields
string_unit: StringUnitTrait Implementations
Sourceimpl Clone for DeviceVariation
impl Clone for DeviceVariation
Sourcefn clone(&self) -> DeviceVariation
fn clone(&self) -> DeviceVariation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceVariation
impl Debug for DeviceVariation
Sourceimpl<'de> Deserialize<'de> for DeviceVariation
impl<'de> Deserialize<'de> for DeviceVariation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DeviceVariation
impl JsonSchema for DeviceVariation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DeviceVariation
impl RefUnwindSafe for DeviceVariation
impl Send for DeviceVariation
impl Sync for DeviceVariation
impl Unpin for DeviceVariation
impl UnsafeUnpin for DeviceVariation
impl UnwindSafe for DeviceVariation