pub struct Localization {
pub string_unit: Option<StringUnit>,
pub variations: Option<Variations>,
pub substitutions: Option<BTreeMap<String, Value>>,
}Fields
string_unit: Option<StringUnit>variations: Option<Variations>substitutions: Option<BTreeMap<String, Value>>Trait Implementations
Sourceimpl Clone for Localization
impl Clone for Localization
Sourcefn clone(&self) -> Localization
fn clone(&self) -> Localization
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Localization
impl Debug for Localization
Sourceimpl<'de> Deserialize<'de> for Localization
impl<'de> Deserialize<'de> for Localization
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Localization
impl JsonSchema for Localization
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Localization
impl RefUnwindSafe for Localization
impl Send for Localization
impl Sync for Localization
impl Unpin for Localization
impl UnsafeUnpin for Localization
impl UnwindSafe for Localization