pub struct PluralVariation {
pub string_unit: StringUnit,
}Fields
string_unit: StringUnitTrait Implementations
Sourceimpl Clone for PluralVariation
impl Clone for PluralVariation
Sourcefn clone(&self) -> PluralVariation
fn clone(&self) -> PluralVariation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PluralVariation
impl Debug for PluralVariation
Sourceimpl<'de> Deserialize<'de> for PluralVariation
impl<'de> Deserialize<'de> for PluralVariation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PluralVariation
impl JsonSchema for PluralVariation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PluralVariation
impl RefUnwindSafe for PluralVariation
impl Send for PluralVariation
impl Sync for PluralVariation
impl Unpin for PluralVariation
impl UnsafeUnpin for PluralVariation
impl UnwindSafe for PluralVariation