pub struct StringEntry {
pub extraction_state: Option<ExtractionState>,
pub should_translate: bool,
pub comment: Option<String>,
pub localizations: Option<OrderedMap<String, Localization>>,
}Fields
extraction_state: Option<ExtractionState>should_translate: boolcomment: Option<String>localizations: Option<OrderedMap<String, Localization>>Trait Implementations
Sourceimpl Clone for StringEntry
impl Clone for StringEntry
Sourcefn clone(&self) -> StringEntry
fn clone(&self) -> StringEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StringEntry
impl Debug for StringEntry
Sourceimpl<'de> Deserialize<'de> for StringEntry
impl<'de> Deserialize<'de> for StringEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StringEntry
impl JsonSchema for StringEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StringEntry
impl RefUnwindSafe for StringEntry
impl Send for StringEntry
impl Sync for StringEntry
impl Unpin for StringEntry
impl UnsafeUnpin for StringEntry
impl UnwindSafe for StringEntry