pub struct StringUnit {
pub state: TranslationState,
pub value: String,
}Fields
state: TranslationStatevalue: StringTrait Implementations
Sourceimpl Clone for StringUnit
impl Clone for StringUnit
Sourcefn clone(&self) -> StringUnit
fn clone(&self) -> StringUnit
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StringUnit
impl Debug for StringUnit
Sourceimpl<'de> Deserialize<'de> for StringUnit
impl<'de> Deserialize<'de> for StringUnit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StringUnit
impl JsonSchema for StringUnit
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StringUnit
impl RefUnwindSafe for StringUnit
impl Send for StringUnit
impl Sync for StringUnit
impl Unpin for StringUnit
impl UnsafeUnpin for StringUnit
impl UnwindSafe for StringUnit