pub struct Variations {
pub plural: Option<BTreeMap<String, PluralVariation>>,
pub device: Option<BTreeMap<DeviceCategory, DeviceVariation>>,
}Fields
plural: Option<BTreeMap<String, PluralVariation>>device: Option<BTreeMap<DeviceCategory, DeviceVariation>>Trait Implementations
Sourceimpl Clone for Variations
impl Clone for Variations
Sourcefn clone(&self) -> Variations
fn clone(&self) -> Variations
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Variations
impl Debug for Variations
Sourceimpl<'de> Deserialize<'de> for Variations
impl<'de> Deserialize<'de> for Variations
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Variations
impl JsonSchema for Variations
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Variations
impl RefUnwindSafe for Variations
impl Send for Variations
impl Sync for Variations
impl Unpin for Variations
impl UnsafeUnpin for Variations
impl UnwindSafe for Variations